@@ -402,7 +402,7 @@ int CloseTray(DRIVE *drive)
 }
 
 
-int GetDiscType(DRIVE *drive, int *disc_type_ret)
+int GetDiscType(DRIVE *drive, int *disc_type_ret, BOOL bWaitDisc)
 {
 	BYTE cdb[12];
 	int ret;
@@ -412,7 +412,7 @@ int GetDiscType(DRIVE *drive, int *disc_type_ret)
 
 	*disc_type_ret = DT_UNKNOWN;
 
-	ret = CheckReady(drive);
+	ret = CheckReady(drive, bWaitDisc);
 	if(ret!=RET_OK){
 		return ret;
 	}
@@ -441,44 +441,61 @@ int GetDiscType(DRIVE *drive, int *disc_type_ret)
 	return ret;
 }
 
-int CheckReady(DRIVE *drive)
+int CheckReady(DRIVE *drive, BOOL bWaitDisc)
 {
 	int ret;
 	BOOL bGood=FALSE;
 	BOOL bEjected=FALSE;
 
 	while(bGood==FALSE){
-		if(UICheckAbort()){
-			return RET_ABORT;
+	  if(UICheckAbort()){
+		return RET_ABORT;
+	  }
+	  ret = SendTestUnitReady(drive);
+	  if(ret==RET_OK){
+		bGood=TRUE;
+	  }
+	  else{
+		if(SD_SENSEKEY(drive)==0x02 &&
+		   SD_ASC(drive)==0x04 &&
+		   SD_ASCQ(drive)==0x01){
+			  /* becoming ready */
 		}
-		ret = SendTestUnitReady(drive);
-		if(ret==RET_OK){
-			bGood=TRUE;
+		else if(SD_SENSEKEY(drive)==0x06 &&
+				SD_ASC(drive)==0x28 &&
+				SD_ASCQ(drive)==0x00){
+			  /* medium change */
+		}
+		else if(SD_SENSEKEY(drive)==0x06 &&
+				SD_ASC(drive)==0x29 &&
+				SD_ASCQ(drive)==0x00){
+			  /* power on, reset */
 		}
-		else{
-			if(SD_SENSEKEY(drive)==0x02 && SD_ASC(drive)==0x04 && SD_ASCQ(drive)==0x01){
-				/* becoming ready */
-			}
-			else if(SD_SENSEKEY(drive)==0x06 && SD_ASC(drive)==0x28 && SD_ASCQ(drive)==0x00){
-				/* medium change */
-			}
-			else if(SD_SENSEKEY(drive)==0x06 && SD_ASC(drive)==0x29 && SD_ASCQ(drive)==0x00){
-				/* power on, reset */
-			}
 #if 0
-			else if(SD_SENSEKEY(drive)==0x02 && SD_ASC(drive)==0x3a && SD_ASCQ(drive)==0x00){
-				/* medium not present */
-			}
-#endif
-			else{
-				/* Eject */
-				if(bEjected==FALSE){
-					OpenTray(drive);
-					bEjected=TRUE;
-				}
-			}
-			/*Sleep(100);*/
+		else if(SD_SENSEKEY(drive)==0x02 &&
+				SD_ASC(drive)==0x3a &&
+				SD_ASCQ(drive)==0x00){
+			  /* medium not present */
 		}
+#endif
+		else{
+		  if(bWaitDisc){
+				/* Eject */
+			if(bEjected==FALSE){
+			  OpenTray(drive);
+			  bEjected=TRUE;
+			}
+		  }
+		  else{
+			return RET_NG;
+		  }
+		}
+#ifdef WIN32
+		Sleep(1000);
+#else
+		sleep(1);
+#endif
+	  }
 	}
 
 	return RET_OK;
