@@ -8,8 +8,7 @@
 extern "C" {
 #endif
 
-extern int CreateLog(DRIVE *pReader, const char *pReaderInquiry,
-		     DRIVE *pWriter, const char *pWriterInquiry);
+extern int CreateLog(DRIVE *pReader, DRIVE *pWriter, int nWriter);
 
 extern void CmdLog(DRIVE *drive, BYTE *cdb, DWORD buflen, BYTE reqflag,
 		   int retcode);
