@@ -10,7 +10,7 @@
 extern "C" {
 #endif
 
-int CopyDisc(DRIVE *reader, DRIVE *writer);
+int CopyDisc(DRIVE *reader, DRIVE *writer, int num_writer);
 
 #ifdef __cplusplus
 }
