@@ -220,25 +220,36 @@ int SetOption(DRIVE *reader, DRIVE *writer, int disc_type)
 		g_Option.test_write = FALSE;
 	}
 	else{
-		ret = SendModeSense(writer, MSPC_CHANGEABLE, 5);
-		if(ret!=RET_OK){
-			DispCommandError(writer);
-			return ret;
-		}
-		mp05 = (struct _MODEPAGE05 *)(writer->data_buf + (writer->atapi ? 8:16));
-		if(mp05->BUFE){
-			g_Option.bufe = TRUE;
-			g_Option.flags |= OPFLG_BUFE;
-		}
-		if(mp05->test_write){
+		if(writer==NULL){
+			g_Option.bufe = FALSE;
 			g_Option.test_write = FALSE;
-			g_Option.flags |= OPFLG_TESTWRITE;
+		}
+		else{
+			ret = SendModeSense(writer, MSPC_CHANGEABLE, 5);
+			if(ret!=RET_OK){
+				DispCommandError(writer);
+				return ret;
+			}
+			mp05 = (struct _MODEPAGE05 *)(writer->data_buf + (writer->atapi ? 8:16));
+			if(mp05->BUFE){
+				g_Option.bufe = TRUE;
+				g_Option.flags |= OPFLG_BUFE;
+			}
+			if(mp05->test_write){
+				g_Option.test_write = FALSE;
+				g_Option.flags |= OPFLG_TESTWRITE;
+			}
 		}
 	}
 
-	if(reader->hid != writer->hid || reader->tid != writer->tid){
+	if(reader!=NULL && writer!=NULL){
+		if(reader->hid != writer->hid || reader->tid != writer->tid){
+			g_Option.on_the_fly = TRUE;
+			g_Option.flags |= OPFLG_ONTHEFLY;
+		}
+	}
+	else{
 		g_Option.on_the_fly = TRUE;
-		g_Option.flags |= OPFLG_ONTHEFLY;
 	}
 
 	if(DT_DVD_FAMILY(disc_type)){
