@@ -4,8 +4,8 @@
 #include <aspi.h>
 #include <option.h>
 
-//#undef USE_THREAD
-#define USE_THREAD
+#undef USE_THREAD
+//#define USE_THREAD
 
 #ifdef __cplusplus
 extern "C" {
@@ -36,6 +36,7 @@ void UIMeter2Initialize(const char *message);
 void UIMeter1Update(int percentage);
 void UIMeter2Update(int percentage);
 void UIDispInfo(const char *message);
+int UIFileDialog(BOOL bOpen, char *filename, int size, const char *suffix);
 
 int UISetting(OPTIONS *option);
 
