@@ -102,6 +102,9 @@ CEnbanFukusyaDlg::CEnbanFukusyaDlg(CWnd* pParent /*=NULL*/)
 	m_bRunning = FALSE;
 	m_nWindowSizeStep = -1;
 	m_bScanDone = FALSE;
+	m_nAllWritableDrives = -1;
+	m_nReadDriveISO = -1;
+	m_nWriteDriveISO = -1;
 }
 
 void CEnbanFukusyaDlg::DoDataExchange(CDataExchange* pDX)
@@ -495,6 +498,16 @@ LRESULT CEnbanFukusyaDlg::OnKickIdle(WPARAM wParam, LPARAM lParam)
 		}
 	}
 
+	if(m_CmbWriter.GetCount() >= 2){
+		m_CmbWriter.AddString("L^pfBXN}ς̑Su");
+		m_nAllWritableDrives = m_CmbWriter.GetCount()-1;
+	}
+
+	m_CmbReader.AddString("ISOC[Wt@C");
+	m_nReadDriveISO = m_CmbReader.GetCount()-1;
+	m_CmbWriter.AddString("ISOC[Wt@C");
+	m_nWriteDriveISO = m_CmbWriter.GetCount()-1;
+
 	m_bScanDone = TRUE;
 //	{
 //		MsgDlg.Disp("Q MB_YESNOCANCEL ̃eXg", NULL, MB_YESNOCANCEL|MB_ICONEXCLAMATION);
@@ -554,10 +567,12 @@ void CEnbanFukusyaDlg::OnOK()
 	CThemeMessageDlg MsgDlg;
 	CThemeSet *pThemeClass = ((CEnbanFukusyaApp *)AfxGetApp())->GetThemeClass();
 	int ret;
-	DRIVE reader, writer;
+	DRIVE reader, writer, *writerp=NULL;
 	int sel_reader, sel_writer;
 	DWORD timeout = 5*60;	/* R}h^CAEg=5 */
 	BOOL bOneDrive = FALSE;
+	int nWriter;
+	int nIndex;
 
 	MsgDlg.SetTheme(pThemeClass);
 
@@ -569,17 +584,24 @@ void CEnbanFukusyaDlg::OnOK()
 	if(sel_writer==CB_ERR)
 		return;
 
-	if(m_pReaderDrives[sel_reader].hid == m_pWriterDrives[sel_writer].hid &&
-		m_pReaderDrives[sel_reader].tid == m_pWriterDrives[sel_writer].tid){
-		bOneDrive = TRUE;
+	if(sel_writer != m_nAllWritableDrives &&
+		sel_writer != m_nWriteDriveISO &&
+		sel_reader != m_nReadDriveISO){
+		if(m_pReaderDrives[sel_reader].hid == m_pWriterDrives[sel_writer].hid &&
+			m_pReaderDrives[sel_reader].tid == m_pWriterDrives[sel_writer].tid){
+			bOneDrive = TRUE;
+		}
 	}
+
 	// hCuڑ
 	::ZeroMemory(&reader, sizeof(DRIVE));
 	::ZeroMemory(&writer, sizeof(DRIVE));
 	ret = InitializeDrive(&reader, 0x10000, 50);
 	if(ret==RET_OK){
-		ret = SetAspiSetting(&reader, &m_pReaderDrives[sel_reader].hid,
+		if(sel_reader != m_nReadDriveISO){
+			ret = SetAspiSetting(&reader, &m_pReaderDrives[sel_reader].hid,
 									&m_pReaderDrives[sel_reader].tid, &timeout);
+		}
 	}
 	if(ret!=RET_OK){
 		csTemp.LoadString(IDS_DRIVEINITERROR);
@@ -588,21 +610,91 @@ void CEnbanFukusyaDlg::OnOK()
 	}
 	if(bOneDrive){
 		::CopyMemory(&writer, &reader, sizeof(DRIVE));
+		writerp = &writer;
+		nWriter=1;
 	}
 	else{
-		ret = InitializeDrive(&writer, 0, 50);
-		if(ret==RET_OK){
+		if(sel_writer == m_nAllWritableDrives){
+			nWriter=0;
+			for(nIndex=0; strlen((LPCTSTR)m_pWriterDrives[nIndex].inqdata)!=0; nIndex++){
+				if(m_pReaderDrives[sel_reader].hid == m_pWriterDrives[nIndex].hid &&
+					m_pReaderDrives[sel_reader].tid == m_pWriterDrives[nIndex].tid){
+					/* ǎ摕u͖ */
+					continue;
+				}
+				writerp = (DRIVE *)realloc(writerp, (nWriter+1)*sizeof(DRIVE));
+				if(writerp==NULL){
+					FreeDrive(&reader);
+					csTemp.LoadString(IDS_DRIVEINITERROR);
+					MsgDlg.Disp(csTemp, NULL, MB_ICONSTOP);
+					for(nIndex=0; nIndex<nWriter; nIndex++){
+						writerp[nIndex].bufsize = 0;
+						writerp[nIndex].data_buf = NULL;
+						FreeDrive(&writerp[nIndex]);
+					}
+					free(writerp);
+					return;
+				}
+				::ZeroMemory(&writerp[nWriter], sizeof(DRIVE));
+				ret = InitializeDrive(&writerp[nWriter], 0, 50);
+				if(ret!=RET_OK){
+					FreeDrive(&reader);
+					csTemp.LoadString(IDS_DRIVEINITERROR);
+					MsgDlg.Disp(csTemp, NULL, MB_ICONSTOP);
+					for(nIndex=0; nIndex<nWriter; nIndex++){
+						writerp[nIndex].bufsize = 0;
+						writerp[nIndex].data_buf = NULL;
+						FreeDrive(&writerp[nIndex]);
+					}
+					free(writerp);
+					return;
+				}
+				// writer̃obt@reader̃obt@L
+				writerp[nWriter].data_buf = reader.data_buf;
+				writerp[nWriter].bufsize = reader.bufsize;
+				ret = SetAspiSetting(&writerp[nWriter], &m_pWriterDrives[nIndex].hid,
+											&m_pWriterDrives[nIndex].tid, &timeout);
+				if(ret!=RET_OK){
+					FreeDrive(&reader);
+					csTemp.LoadString(IDS_DRIVEINITERROR);
+					MsgDlg.Disp(csTemp, NULL, MB_ICONSTOP);
+					for(nIndex=0; nIndex<=nWriter; nIndex++){
+						writerp[nIndex].bufsize = 0;
+						writerp[nIndex].data_buf = NULL;
+						FreeDrive(&writerp[nIndex]);
+					}
+					free(writerp);
+					return;
+				}
+				nWriter++;
+			}
+		}
+		else{
+			ret = InitializeDrive(&writer, 0, 50);
+			if(ret!=RET_OK){
+				FreeDrive(&reader);
+				csTemp.LoadString(IDS_DRIVEINITERROR);
+				MsgDlg.Disp(csTemp, NULL, MB_ICONSTOP);
+				return;
+			}
 			// writer̃obt@reader̃obt@L
 			writer.data_buf = reader.data_buf;
 			writer.bufsize = reader.bufsize;
-			ret = SetAspiSetting(&writer, &m_pWriterDrives[sel_writer].hid,
-										&m_pWriterDrives[sel_writer].tid, &timeout);
-		}
-		if(ret!=RET_OK){
-			FreeDrive(&reader);
-			csTemp.LoadString(IDS_DRIVEINITERROR);
-			MsgDlg.Disp(csTemp, NULL, MB_ICONSTOP);
-			return;
+			if(sel_writer != m_nWriteDriveISO){
+				ret = SetAspiSetting(&writer, &m_pWriterDrives[sel_writer].hid,
+											&m_pWriterDrives[sel_writer].tid, &timeout);
+				if(ret!=RET_OK){
+					FreeDrive(&reader);
+					writer.bufsize = 0;
+					writer.data_buf = NULL;
+					FreeDrive(&writer);
+					csTemp.LoadString(IDS_DRIVEINITERROR);
+					MsgDlg.Disp(csTemp, NULL, MB_ICONSTOP);
+					return;
+				}
+			}
+			nWriter = 1;
+			writerp = &writer;
 		}
 	}
 
@@ -616,15 +708,22 @@ void CEnbanFukusyaDlg::OnOK()
 	m_BtnOK.SetWindowText(csTemp);
 	m_BtnOK.SetFocus();
 
-	ret = CopyDisc(&reader, &writer);
+	ret = CopyDisc(sel_reader==m_nReadDriveISO ? NULL : &reader,
+					sel_writer==m_nWriteDriveISO ? NULL : writerp, nWriter);
 	switch(ret){
 	case RET_ABORT:
 		nMessageID = IDS_PROCESS_ABORTED;
 		nMBFlags = MB_OK|MB_ICONINFORMATION;
 		break;
 	case RET_OK:
-		nMessageID = IDS_PROCESS_SUCCESS;
-		nMBFlags = MB_YESNO|MB_ICONINFORMATION;
+		if(sel_writer==m_nWriteDriveISO){
+			nMessageID = IDS_PROCESS_SUCCESS_IMAGE;
+			nMBFlags = MB_OK|MB_ICONINFORMATION;
+		}
+		else{
+			nMessageID = IDS_PROCESS_SUCCESS;
+			nMBFlags = MB_YESNO|MB_ICONINFORMATION;
+		}
 		break;
 	default:
 		nMessageID = IDS_PROCESS_ERRSTOP;
@@ -635,11 +734,12 @@ void CEnbanFukusyaDlg::OnOK()
 	ret = MsgDlg.Disp(csTemp, NULL, nMBFlags);
 	if(ret==IDYES){
 		if(nMessageID==IDS_PROCESS_ERRSTOP){
-			CreateLog(&reader, (LPCTSTR)m_pReaderDrives[sel_reader].inqdata,
-						&writer, (LPCTSTR)m_pWriterDrives[sel_writer].inqdata);
+			CreateLog(&reader, writerp, nWriter);
 		}
 		else if(nMessageID==IDS_PROCESS_SUCCESS){
-			OpenTray(&writer);
+			for(nIndex=0; nIndex<nWriter; nIndex++){
+				OpenTray(&writerp[nIndex]);
+			}
 		}
 	}
 
@@ -651,13 +751,22 @@ void CEnbanFukusyaDlg::OnOK()
 	m_CmbWriter.EnableWindow(TRUE);
 	m_bRunning=FALSE;
 
-	// LĂobt@؂藣
-	writer.bufsize = 0;
-	writer.data_buf = NULL;
+	if(!bOneDrive){
+		for(nIndex=0; nIndex<nWriter; nIndex++){
+			// LĂobt@؂藣
+			writerp[nIndex].bufsize = 0;
+			writerp[nIndex].data_buf = NULL;
+		}
+	}
 	// hCuڑ
 	FreeDrive(&reader);
 	if(!bOneDrive){
-		FreeDrive(&writer);
+		for(nIndex=0; nIndex<nWriter; nIndex++){
+			FreeDrive(&writerp[nIndex]);
+		}
+		if(writerp != &writer){
+			free(writerp);
+		}
 	}
 
 	SendMessage(WM_USER_UICTL, UICTL_METER2INIT, NULL);
