@@ -97,3 +97,23 @@ int UISetting(OPTIONS *option)
 	return ::SendMessage(g_hWnd, WM_USER_UICTL, UICTL_SETTING, (LPARAM)option);
 }
 
+int UIFileDialog(BOOL bOpen, char *filename, int size, const char *suffix)
+{
+	CString csFilter;
+	if(suffix != NULL){
+		csFilter.Format("%s files (*.%s)|*.%s|All Files (*.*)|*.*||", suffix, suffix, suffix);
+	}
+	else{
+		csFilter = "All Files (*.*)|*.*||";
+	}
+	CFileDialog dlg(bOpen, suffix, filename, OFN_HIDEREADONLY|OFN_OVERWRITEPROMPT,
+					csFilter, NULL);
+	if(dlg.DoModal()==IDOK){
+		CString csFullPath = dlg.GetPathName();
+		strncpy(filename, (LPCTSTR)csFullPath, size);
+		filename[size-1] = '\0';
+		return UIDMRET_OK;
+	}
+	return UIDMRET_CANCEL;				
+}
+
